//
//  ImagiumOptions.swift
//  
//
//  Created by Thibaut Schmitt on 24/01/2022.
//

import Foundation
import ArgumentParser

struct ImagiumOptions: ParsableArguments {
    @Flag(name: .customShort("f"), help: "Should force script execution")
    var forceExecution = false
    
    @Flag(name: .customShort("F"), help: "Regenerate all images")
    var forceExecutionAndGeneration = false
    
    @Argument(help: "Input files where strings ared defined.", transform: { $0.replaceTiltWithHomeDirectoryPath() })
    var inputFile: String
    
    @Option(help: "Xcassets path where to generate images.", transform: { $0.replaceTiltWithHomeDirectoryPath() })
    var xcassetsPath: String
    
    @Option(help: "Path where to generate the extension.", transform: { $0.replaceTiltWithHomeDirectoryPath() })
    var extensionOutputPath: String
    
    @Option(help: "Extension name. If not specified, it will generate an UIImage extension. Using default extension name will generate static property.")
    var extensionName: String = Imagium.defaultExtensionName
    
    @Option(help: "Extension suffix. Ex: MyApp, it will generate {extensionName}+Image{extensionSuffix}.swift")
    var extensionSuffix: String = ""
}


/*
 swift run -c release Imagium $FORCE_FLAG "./Images/sampleImages.txt" \
    --xcassets-path "./Images/imagium.xcassets" \
    --extension-output-path "./Images/Generated" \
    --extension-name "UIImage" \
    --extension-suffix "GenAllScript"
 */
