//
//  TagsGenerator.swift
//  
//
//  Created by Thibaut Schmitt on 10/01/2022.
//

import Foundation
import ToolCore
import CoreVideo

class TagsGenerator {
    static func writeExtensionFiles(sections: [Section], lang: String, tags: [String], staticVar: Bool, extensionName: String, extensionFilePath: String) {
        let extensionHeader = Self.getHeader(extensionClassname: extensionName)
        let extensionFooter = Self.getFooter()
        
        let extensionContent: String = {
            var content = ""
            sections.forEach { section in
                // Check that at least one string will be generated
                guard section.hasOneOrMoreMatchingTags(tags: tags) else {
                    return // Go to next section
                }
                
                content += "\n\t// MARK: - \(section.name)"
                section.definitions.forEach { definition in
                    if staticVar {
                        content += "\n\n\(definition.getStaticProperty(forLang: lang))"
                    } else {
                        content += "\n\n\(definition.getProperty(forLang: lang))"
                    }
                }
                content += "\n"
            }
            return content
        }()
        
        // Create file if not exists
        let fileManager = FileManager()
        if fileManager.fileExists(atPath: extensionFilePath) == false {
            Shell.shell("touch", "\(extensionFilePath)")
        }
        
        // Create extension content
        let extensionFileContent = [extensionHeader, extensionContent, extensionFooter].joined(separator: "\n")
        
        // Write content
        let extensionFilePathURL = URL(fileURLWithPath: extensionFilePath)
        do {
            try extensionFileContent.write(to: extensionFilePathURL, atomically: true, encoding: .utf8)
        } catch (let error) {
            let error = StringiumError.writeFile(extensionFilePath, error.localizedDescription)
            print(error.localizedDescription)
            Stringium.exit(withError: error)
        }
    }
    
    private static func getHeader(extensionClassname: String) -> String {
            """
            // Generated by ResgenSwift.Strings.Tags \(ResgenSwiftVersion)
            
            // typelias Tags = String
            
            import UIKit
            
            extension \(extensionClassname) {
            """
    }
    
    private static func getFooter() -> String {
            """
            }
            """
    }
}
